GeneSampGBM: Data from the Parsons et al. 2008 study: Number of samples
for each gene and screen type
Description
Number of samples analyzed for each gene and
screen type from the
Parsons et al. 2008 glioblastoma multiforme (GBM) study.Format
The number of samples in the GBM study from Parsons et al.,
broken down by
gene and screen (Discovery and Prevalence).
The object is a data frame, with the variables:
Gene, Screen, and NrSamp (number of samples).
The two possible values for Screen are Disc ("Discovery")
and Prev ("Prevalence").References
Parsons DW, Jones S, Zhang X, Lin JCH, Leary RJ, Angenendt P, Mankoo P,
Carter H, Siu I, et al.
An integrated genomic analysis of human glioblastoma multiforme.
Science. DOI: 10.1126/science.1164382 Parmigiani G, Lin J, Boca S, Sjoeblom T, Kinzler KW,
Velculescu VE, Vogelstein B. Statistical methods for the analysis of
cancer genome sequencing data.
http://www.bepress.com/jhubiostat/paper126/
See Also
cma.scores, cma.fdr,
cma.set.stat, cma.set.sim,
SimMethodsSims-class,
GeneAlterGBM,
GeneCovGBM