GeneSampPancreas: Data from the Jones et al. 2008 study: Number of samples
for each gene and screen type
Description
Number of samples analyzed for each gene and
screen type from the
Jones et al. 2008 pancreatic cancer study.Usage
data(JonesPancreas08)
Format
The number of samples in the pancreatic cancer study from Jones et
al., broken down by
gene and screen (Discovery and Prevalence).
The object is a data frame, with the variables:
Gene, Screen, and NrSamp (number of samples).
The two possible values for Screen are Disc ("Discovery")
and Prev ("Prevalence").References
Jones S, Zhang X, Parsons DW, Lin JC, Leary RJ, Angenendt P, Mankoo P,
Carter H, Kamiyama H, Jimeno A, et al.
Core signaling pathways in human pancreatic cancers revealed by global
genomic analyses.
Science. DOI: 10.1126/science.1164368 Parmigiani G, Lin J, Boca S, Sjoeblom T, Kinzler KW,
Velculescu VE, Vogelstein B. Statistical methods for the analysis of
cancer genome sequencing data.
http://www.bepress.com/jhubiostat/paper126/
See Also
cma.scores, cma.fdr,
cma.set.stat, cma.set.sim,
SimMethodsSims-class,
GeneAlterPancreas,
GeneCovPancreas